@@ -88,12 +88,12 @@ function(           data.prep.obj = NULL,
       
       if(genoud == TRUE) # if user wants genoud as well
       {
-      require(rgenoud)                # we run genoud first
+      # we run genoud first
       cat("\n****************",
          "\n genoud() requested for optimization\n","\n"
         )
 
-      rgV.genoud <- genoud(
+      rgV.genoud <- rgenoud::genoud(
                              fn.V, 
                              nvarsV, 
                              X0.scaled = X0.scaled,
@@ -239,7 +239,7 @@ function(           data.prep.obj = NULL,
     } else {
     # LowRankQP
      if(quadopt=="LowRankQP"){
-      res <- LowRankQP(Vmat=H,dvec=c,Amat=A,bvec=1,uvec=rep(1,length(c)),method="LU")
+      res <- LowRankQP::LowRankQP(Vmat=H,dvec=c,Amat=A,bvec=1,uvec=rep(1,length(c)),method="LU")
       solution.w <- as.matrix(res$alpha)
      } 
     }
