@@ -3,7 +3,7 @@ function (libname, pkgname)
 {
    # echo output to screen
    packageStartupMessage("##\n## Synth Package: Implements Synthetic Control Methods.\n")
-   packageStartupMessage("## See http://www.mit.edu/~jhainm/software.htm for additional information.\n\n")
+   packageStartupMessage("## See https://web.stanford.edu/~jhain/synthpage.html for additional information.\n\n")
 }
 
 
